package com.yijia.integral.mapper;

import java.util.List;
import com.yijia.integral.domain.CustomerPoints;

/**
 * 用户积分Mapper接口
 * 
 * @author yijia
 * @date 2021-02-24
 */
public interface CustomerPointsMapper 
{
    /**
     * 查询用户积分
     * 
     * @param id 用户积分ID
     * @return 用户积分
     */
    public CustomerPoints selectCustomerPointsById(Long id);

    /**
     * 查询用户积分列表
     * 
     * @param customerPoints 用户积分
     * @return 用户积分集合
     */
    public List<CustomerPoints> selectCustomerPointsList(CustomerPoints customerPoints);

    /**
     * 新增用户积分
     * 
     * @param customerPoints 用户积分
     * @return 结果
     */
    public int insertCustomerPoints(CustomerPoints customerPoints);

    /**
     * 修改用户积分
     * 
     * @param customerPoints 用户积分
     * @return 结果
     */
    public int updateCustomerPoints(CustomerPoints customerPoints);

    /**
     * 删除用户积分
     * 
     * @param id 用户积分ID
     * @return 结果
     */
    public int deleteCustomerPointsById(Long id);

    /**
     * 批量删除用户积分
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteCustomerPointsByIds(Long[] ids);
}
